This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] gcc/*.[ch]: Fix comment typos. Follow spellingconventions.


Hi,

Committed as obvious.

Kazu Hirata

2004-06-26  Kazu Hirata  <kazu@cs.umass.edu>

	* c-typeck.c, cfgexpand.c, ddg.c, ddg.h, df.c, fold-const.c,
	gcov.c, gimplify.c, modulo-sched.c, passes.c, tree-cfg.c,
	tree-mudflap.c, tree-nrv.c, tree-outof-ssa.c, tree-ssa-dom.c,
	tree-ssa-dse.c, tree-ssa-operands.c, tree-ssa-pre.c,
	tree-tailcall.c: Fix comment typos.  Follow spelling
	conventions.

Index: c-typeck.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/c-typeck.c,v
retrieving revision 1.331
diff -u -r1.331 c-typeck.c
--- c-typeck.c	24 Jun 2004 23:12:28 -0000	1.331
+++ c-typeck.c	26 Jun 2004 04:46:47 -0000
@@ -6490,7 +6490,7 @@
     {
       tree inner_if = then_block;
 
-      /* We know from the grammer productions that there is an IF nested
+      /* We know from the grammar productions that there is an IF nested
 	 within THEN_BLOCK.  Due to labels and c99 conditional declarations,
 	 it might not be exactly THEN_BLOCK, but should be the last
 	 non-container statement within.  */
@@ -6547,7 +6547,7 @@
 /* Emit a general-purpose loop construct.  START_LOCUS is the location of
    the beginning of the loop.  COND is the loop condition.  COND_IS_FIRST
    is false for DO loops.  INCR is the FOR increment expression.  BODY is
-   the statement controled by the loop.  BLAB is the break label.  CLAB is
+   the statement controlled by the loop.  BLAB is the break label.  CLAB is
    the continue label.  Everything is allowed to be NULL.  */
 
 void
Index: cfgexpand.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cfgexpand.c,v
retrieving revision 2.1
diff -u -r2.1 cfgexpand.c
--- cfgexpand.c	19 Jun 2004 15:33:05 -0000	2.1
+++ cfgexpand.c	26 Jun 2004 04:46:47 -0000
@@ -389,7 +389,7 @@
    We do conversion per basic block and preserve/update the tree CFG.
    This implies we have to do some magic as the CFG can simultaneously
    consist of basic blocks containing RTL and GIMPLE trees.  This can
-   confuse the CFG hooks, so be curefull to not manipulate CFG during
+   confuse the CFG hooks, so be careful to not manipulate CFG during
    the expansion.  */
 
 static void
Index: ddg.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ddg.c,v
retrieving revision 1.3
diff -u -r1.3 ddg.c
--- ddg.c	30 May 2004 18:32:24 -0000	1.3
+++ ddg.c	26 Jun 2004 04:46:47 -0000
@@ -383,7 +383,7 @@
   get_block_head_tail (g->bb->index, &head, &tail);
   sched_analyze (&tmp_deps, head, tail);
 
-  /* Build intra-loop data dependecies using the scheduler dependecy
+  /* Build intra-loop data dependencies using the scheduler dependency
      analysis.  */
   for (i = 0; i < g->num_nodes; i++)
     {
@@ -509,7 +509,7 @@
   if (!g->closing_branch)
     abort ();  /* Found no branch in DDG.  */
 
-  /* Build the data dependecy graph.  */
+  /* Build the data dependency graph.  */
   build_intra_loop_deps (g);
   build_inter_loop_deps (g, df);
   return g;
Index: ddg.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ddg.h,v
retrieving revision 1.3
diff -u -r1.3 ddg.h
--- ddg.h	3 Jun 2004 15:01:08 -0000	1.3
+++ ddg.h	26 Jun 2004 04:46:47 -0000
@@ -92,7 +92,7 @@
   /* REG or MEM dependency.  */
   dep_data_type data_type;
 
-  /* Latency of the depedency.  */
+  /* Latency of the dependency.  */
   int latency;
 
   /* The distance: number of loop iterations the dependency crosses.  */
Index: df.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/df.c,v
retrieving revision 1.67
diff -u -r1.67 df.c
--- df.c	15 Jun 2004 22:15:20 -0000	1.67
+++ df.c	26 Jun 2004 04:46:47 -0000
@@ -2348,7 +2348,7 @@
   return last;
 }
 
-/* Alternative entry point to the analysis.  Analyse just the part of the cfg
+/* Alternative entry point to the analysis.  Analyze just the part of the cfg
    graph induced by BLOCKS.
    
    TODO I am not quite sure how to avoid code duplication with df_analyze_1
Index: fold-const.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fold-const.c,v
retrieving revision 1.410
diff -u -r1.410 fold-const.c
--- fold-const.c	25 Jun 2004 01:28:34 -0000	1.410
+++ fold-const.c	26 Jun 2004 04:46:48 -0000
@@ -3717,7 +3717,7 @@
 
 
 	  /* If we're converting arg0 from an unsigned type, to exp,
-	     a signed type,  we will be doing the compairson as unsigned.
+	     a signed type,  we will be doing the comparison as unsigned.
 	     The tests above have already verified that LOW and HIGH
 	     are both positive.
 
Index: gcov.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/gcov.c,v
retrieving revision 1.79
diff -u -r1.79 gcov.c
--- gcov.c	20 Feb 2004 06:46:41 -0000	1.79
+++ gcov.c	26 Jun 2004 04:46:49 -0000
@@ -1738,7 +1738,7 @@
     }
 }
 
-/* Ouput information about ARC number IX.  Returns nonzero if
+/* Output information about ARC number IX.  Returns nonzero if
    anything is output.  */
 
 static int
Index: gimplify.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/gimplify.c,v
retrieving revision 2.33
diff -u -r2.33 gimplify.c
--- gimplify.c	25 Jun 2004 20:47:45 -0000	2.33
+++ gimplify.c	26 Jun 2004 04:46:49 -0000
@@ -2641,7 +2641,7 @@
   return ret;
 }
 
-/*  Subroutine of above to do simplications of MODIFY_EXPRs based on
+/*  Subroutine of above to do simplifications of MODIFY_EXPRs based on
     the code of the RHS.  We loop for as long as we can do something.  */
 
 static enum gimplify_status
Index: passes.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/passes.c,v
retrieving revision 2.22
diff -u -r2.22 passes.c
--- passes.c	20 Jun 2004 21:31:28 -0000	2.22
+++ passes.c	26 Jun 2004 04:46:49 -0000
@@ -758,7 +758,7 @@
       close_dump_file (DFI_sms, print_rtl, get_insns ());
 
 
-      /* Update the life information, becuase we add pseudos.  */
+      /* Update the life information, because we add pseudos.  */
       max_regno = max_reg_num ();
       allocate_reg_info (max_regno, FALSE, FALSE);
       update_life_info_in_dirty_blocks (UPDATE_LIFE_GLOBAL_RM_NOTES,
Index: tree-cfg.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree-cfg.c,v
retrieving revision 2.20
diff -u -r2.20 tree-cfg.c
--- tree-cfg.c	25 Jun 2004 18:17:53 -0000	2.20
+++ tree-cfg.c	26 Jun 2004 04:46:50 -0000
@@ -3924,7 +3924,7 @@
 	       dest = dest->succ->dest)
 	    {
 	      /* An infinite loop detected.  We redirect the edge anyway, so
-		 that the loop is shrinked into single basic block.  */
+		 that the loop is shrunk into single basic block.  */
 	      if (!bb_ann (dest)->forwardable)
 		break;
 
Index: tree-mudflap.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree-mudflap.c,v
retrieving revision 2.9
diff -u -r2.9 tree-mudflap.c
--- tree-mudflap.c	24 Jun 2004 21:12:49 -0000	2.9
+++ tree-mudflap.c	26 Jun 2004 04:46:50 -0000
@@ -819,7 +819,7 @@
             {
               /* Oh no ... it's probably a variable-length array (VLA).
                  The size and address cannot be computed by merely
-                 looking at the DECL.  See gimplfiy_decl_stmt for the
+                 looking at the DECL.  See gimplify_decl_stmt for the
                  method by which VLA declarations turn into calls to
                  BUILT_IN_STACK_ALLOC.  We assume that multiple
                  VLAs declared later in the same block get allocation 
Index: tree-nrv.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree-nrv.c,v
retrieving revision 2.3
diff -u -r2.3 tree-nrv.c
--- tree-nrv.c	24 Jun 2004 22:47:42 -0000	2.3
+++ tree-nrv.c	26 Jun 2004 04:46:50 -0000
@@ -85,7 +85,7 @@
   else if (TREE_CODE (*tp) == RETURN_EXPR)
     TREE_OPERAND (*tp, 0) = dp->result;
 
-  /* Othewise replace all occurrences of VAR with RESULT.  */
+  /* Otherwise replace all occurrences of VAR with RESULT.  */
   else if (*tp == dp->var)
     *tp = dp->result;
 
Index: tree-ssa-dom.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree-ssa-dom.c,v
retrieving revision 2.15
diff -u -r2.15 tree-ssa-dom.c
--- tree-ssa-dom.c	24 Jun 2004 22:46:56 -0000	2.15
+++ tree-ssa-dom.c	26 Jun 2004 04:46:50 -0000
@@ -649,7 +649,7 @@
   if (dump_file && (dump_flags & TDF_STATS))
     dump_dominator_optimization_stats (dump_file);
 
-  /* We emptyed the hash table earlier, now delete it completely.  */
+  /* We emptied the hash table earlier, now delete it completely.  */
   htab_delete (avail_exprs);
 
   /* It is not necessary to clear CURRDEFS, REDIRECTION_EDGES, VRP_DATA,
@@ -3361,7 +3361,7 @@
   return false;
 }
 
-/* Given STMT and a pointer to the block local defintions BLOCK_DEFS_P,
+/* Given STMT and a pointer to the block local definitions BLOCK_DEFS_P,
    register register all objects set by this statement into BLOCK_DEFS_P
    and CURRDEFS.  */
 
Index: tree-ssa-dse.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree-ssa-dse.c,v
retrieving revision 2.4
diff -u -r2.4 tree-ssa-dse.c
--- tree-ssa-dse.c	17 Jun 2004 18:13:18 -0000	2.4
+++ tree-ssa-dse.c	26 Jun 2004 04:46:51 -0000
@@ -55,7 +55,7 @@
 
    It may help to think of this as first moving the earlier store to
    the point immediately before the later store.  Again, the single
-   use of the virtual defintion and the post-dominance relationship
+   use of the virtual definition and the post-dominance relationship
    ensure that such movement would be safe.  Clearly if there are 
    back to back stores, then the second is redundant.
 
Index: tree-ssa-operands.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree-ssa-operands.c,v
retrieving revision 2.11
diff -u -r2.11 tree-ssa-operands.c
--- tree-ssa-operands.c	23 Jun 2004 00:25:55 -0000	2.11
+++ tree-ssa-operands.c	26 Jun 2004 04:46:51 -0000
@@ -741,7 +741,7 @@
   prev_vops.vuse_ops = VUSE_OPS (ann);
   prev_vops.v_must_def_ops = V_MUST_DEF_OPS (ann);
 
-  /* Dont free the previous values to memory since we're still using them.  */
+  /* Don't free the previous values to memory since we're still using them.  */
   free_v_may_defs (&(ann->v_may_def_ops), false);
   free_vuses (&(ann->vuse_ops), false);
   free_v_must_defs (&(ann->v_must_def_ops), false);
Index: tree-ssa-pre.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree-ssa-pre.c,v
retrieving revision 2.17
diff -u -r2.17 tree-ssa-pre.c
--- tree-ssa-pre.c	23 Jun 2004 20:12:43 -0000	2.17
+++ tree-ssa-pre.c	26 Jun 2004 04:46:51 -0000
@@ -1151,7 +1151,7 @@
   /* Depending on the order we process DOM branches in, the value
      may not have propagated to all the dom children yet during
      this iteration.  In this case, the value will always be in
-     the NEW_SETS for us already, having been propogated from our
+     the NEW_SETS for us already, having been propagated from our
      dominator.  */
   if (genop == NULL)
     genop = find_leader (NEW_SETS (block), expr);
Index: tree-tailcall.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree-tailcall.c,v
retrieving revision 2.12
diff -u -r2.12 tree-tailcall.c
--- tree-tailcall.c	18 Jun 2004 14:05:20 -0000	2.12
+++ tree-tailcall.c	26 Jun 2004 04:46:51 -0000
@@ -210,7 +210,7 @@
       at = SSA_NAME_DEF_STMT (expr);
       bb = bb_for_stmt (at);
 
-      /* The default defininition or defined before the chain.  */
+      /* The default definition or defined before the chain.  */
       if (!bb || !bb->aux)
 	break;
 


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: modulo-sched.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/modulo-sched.c,v
retrieving revision 1.3
diff -u -r1.3 modulo-sched.c
--- modulo-sched.c	8 Jun 2004 21:46:32 -0000	1.3
+++ modulo-sched.c	26 Jun 2004 04:46:49 -0000
@@ -217,7 +217,7 @@
 
 
 /* The following three functions are copied from the current scheduler
-   code in order to use sched_analyze() for computing the dependecies.
+   code in order to use sched_analyze() for computing the dependencies.
    They are used when initializing the sched_info structure.  */
 static const char *
 sms_print_insn (rtx insn, int aligned ATTRIBUTE_UNUSED)
@@ -386,7 +386,7 @@
 				sizeof (struct node_sched_params));
 
   /* Set the pointer of the general data of the node to point to the
-     appropriate sched_params strcture.  */
+     appropriate sched_params structure.  */
   for (i = 0; i < g->num_nodes; i++)
     {
       /* Watch out for aliasing problems?  */
@@ -447,7 +447,7 @@
    of the register live range is more than ii; the number of moves is
    determined according to the following equation:
 		SCHED_TIME (use) - SCHED_TIME (def)   { 1 broken loop-carried
-   nreg_moves = ----------------------------------- - {   dependecnce.
+   nreg_moves = ----------------------------------- - {   dependence.
 			      ii		      { 0 if not.
    This handles the modulo-variable-expansions (mve's) needed for the ps.  */
 static void
@@ -832,7 +832,7 @@
   else
     issue_rate = 1;
 
-  /* Initilize the scheduler.  */
+  /* Initialize the scheduler.  */
   current_sched_info = &sms_sched_info;
   sched_init (NULL);
 
@@ -1526,7 +1526,7 @@
   node_order_params_arr = (nopa) xcalloc (num_nodes,
 					  sizeof (struct node_order_params));
 
   /* Set the aux pointer of each node to point to its order_params strcture.  */
   for (u = 0; u < num_nodes; u++)
     g->nodes[u].aux.info = &node_order_params_arr[u];
 
@@ -1526,7 +1526,7 @@
 					  sizeof (struct node_order_params));
 
-  /* Set the aux pointer of each node to point to its order_params strcture.  */
+  /* Set the aux pointer of each node to point to its order_params structure.  */
   for (u = 0; u < num_nodes; u++)
     g->nodes[u].aux.info = &node_order_params_arr[u];
Index: tree-outof-ssa.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree-outof-ssa.c,v
retrieving revision 2.10
diff -u -r2.10 tree-outof-ssa.c
--- tree-outof-ssa.c	25 Jun 2004 20:33:09 -0000	2.10
+++ tree-outof-ssa.c	26 Jun 2004 04:46:50 -0000
@@ -1183,7 +1183,7 @@
    it is replaced with the RHS of the defining expression.  */
 
 
-/* Dependancy list element.  This can contain either a partition index or a
+/* Dependency list element.  This can contain either a partition index or a
    version number, depending on which list it is in.  */
 
 typedef struct value_expr_d 
@@ -1208,7 +1208,7 @@
   value_expr_p pending_dependence;
 } *temp_expr_table_p;
 
-/* Used to indicate a dependancy on V_MAY_DEFs.  */
+/* Used to indicate a dependency on V_MAY_DEFs.  */
 #define VIRTUAL_PARTITION(table)	(table->virtual_partition)
 
 static temp_expr_table_p new_temp_expr_table (var_map);
@@ -1398,8 +1398,8 @@
 }
 
 
-/* Add a dependancy between the def of ssa VERSION and VAR.  if VAR is 
-   replaceable by an expression, add a dependance each of the elements of the 
+/* Add a dependency between the def of ssa VERSION and VAR.  If VAR is 
+   replaceable by an expression, add a dependence each of the elements of the 
    expression.  These are contained in the pending list.  TAB is the
    expression table.  */
 
@@ -1503,7 +1503,7 @@
 
   version = SSA_NAME_VERSION (def);
 
-  /* Add this expression to the dependancy list for each use partition.  */
+  /* Add this expression to the dependency list for each use partition.  */
   for (i = 0; i < num_use_ops; i++)
     {
       var = USE_OP (uses, i);
@@ -1535,7 +1535,7 @@
   value_expr_p info, tmp;
   int partition;
 
   /* Remove this expression from its dependent lists.  The partition dependance
      list is retained and transfered later to whomever uses this version.  */
   for (info = (value_expr_p) tab->version_info[version]; info; info = tmp)
     {
@@ -1551,7 +1551,7 @@
         abort ();
 #endif
       free_value_expr (tab, tmp);
-      /* Only clear the bit when the dependancy list is emptied via 
+      /* Only clear the bit when the dependency list is emptied via 
          a replacement. Otherwise kill_expr will take care of it.  */
       if (!(tab->partition_dep_list[partition]) && replace)
         bitmap_clear_bit (tab->partition_in_use, partition);
@@ -1610,7 +1610,7 @@
 {
   value_expr_p ptr;
 
-  /* Mark every active expr dependant on this var as not replaceable.  */
+  /* Mark every active expr dependent on this var as not replaceable.  */
   while ((ptr = tab->partition_dep_list[partition]) != NULL)
     finish_expr (tab, ptr->value, false);
 
@@ -1619,7 +1619,7 @@
 }
 
 
-/* This function kills all expressions in TAB which are dependant on virtual 
+/* This function kills all expressions in TAB which are dependent on virtual 
    DEFs.  CLEAR_BIT determines whether partition_in_use gets cleared.  */
 
 static inline void
@@ -1680,7 +1680,7 @@
       if (!ann->has_volatile_ops)
 	check_replaceable (tab, stmt);
 
-      /* Free any unused dependancy lists.  */
+      /* Free any unused dependency lists.  */
       while ((p = tab->pending_dependence))
 	{
 	  tab->pending_dependence = p->next;
@@ -1535,7 +1535,7 @@
   int partition;
 
-  /* Remove this expression from its dependent lists.  The partition dependance
+  /* Remove this expression from its dependent lists.  The partition dependence
      list is retained and transfered later to whomever uses this version.  */
   for (info = (value_expr_p) tab->version_info[version]; info; info = tmp)